public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
Search results ordered by [date|relevance]  view[summary|nested|Atom feed]
thread overview below | download mbox.gz: |
* [gentoo-commits] proj/catalyst:master commit in: targets/support/
@ 2018-10-01 16:30 99% Brian Dolbec
  0 siblings, 0 replies; 1+ results
From: Brian Dolbec @ 2018-10-01 16:30 UTC (permalink / raw
  To: gentoo-commits

commit:     53c9407e9aae76b4d2284f7eba3e650895923555
Author:     Michael Everitt <m.j.everitt <AT> iee <DOT> org>
AuthorDate: Sun Sep  9 17:17:27 2018 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Mon Oct  1 16:19:50 2018 +0000
URL:        https://gitweb.gentoo.org/proj/catalyst.git/commit/?id=53c9407e

Fix mis-spelling of 'received' in chroot-functions.sh

 targets/support/chroot-functions.sh | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/targets/support/chroot-functions.sh b/targets/support/chroot-functions.sh
index 84d90fe9..ceef21ca 100755
--- a/targets/support/chroot-functions.sh
+++ b/targets/support/chroot-functions.sh
@@ -3,19 +3,19 @@
 # Set the profile
 eselect profile set ${clst_target_profile}
 
 # Trap these signals and kill ourselves if recieved
 # Force ourselves to die if any of these signals are recieved
 # most likely our controlling terminal is gone
-trap "echo SIGTERM signal recieved killing $0 with pid $$;kill -9 $$" SIGTERM
-trap "echo SIGHUP signal recieved killing $0 with pid $$;kill -9 $$" SIGHUP
-trap "echo SIGKILL signal recieved killing $0 with pid $$;kill -9 $$" SIGKILL
+trap "echo SIGTERM signal received killing $0 with pid $$;kill -9 $$" SIGTERM
+trap "echo SIGHUP signal received killing $0 with pid $$;kill -9 $$" SIGHUP
+trap "echo SIGKILL signal received killing $0 with pid $$;kill -9 $$" SIGKILL
 
 #SIGINT interrupt character (usually Ctrl-C)
 #	* example: high-level sequence of events
 #	* my process (call it "P") is running
 #	* user types ctrl-c
 #	* kernel recognizes this and generates SIGINT signal
-trap "echo SIGINT signal recieved killing $0 with pid $$;kill -9 $$" SIGINT
+trap "echo SIGINT signal received killing $0 with pid $$;kill -9 $$" SIGINT
 
 # test if CHOST was set on the python side
 if [[ -z "${clst_CHOST}" ]] ; then


^ permalink raw reply related	[relevance 99%]

Results 1-1 of 1 | reverse | options above
-- pct% links below jump to the message on this page, permalinks otherwise --
@@ -3,19 +3,19 @@
 eselect profile set ${clst_target_profile}
 
-# Trap these signals and kill ourselves if recieved
-# Force ourselves to die if any of these signals are recieved
+# Trap these signals and kill ourselves if received
+# Force ourselves to die if any of these signals are received
 # most likely our controlling terminal is gone
2018-10-01 16:30 99% [gentoo-commits] proj/catalyst:master commit in: targets/support/ Brian Dolbec

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox